=======================================================
``psyclone.psyir.transformations.loop_tiling_2d_trans``
=======================================================

.. automodule:: psyclone.psyir.transformations.loop_tiling_2d_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.loop_tiling_2d_trans
